==> tencentcloud-sdk-java-3.0.41-sources.jar: com/tencentcloudapi/mariadb/v20170312/models/DescribeOrdersRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.mariadb.v20170312.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DescribeOrdersRequest  extends AbstractModel{

    /**
    * 待查询的长订单号列表，创建实例、续费实例、扩容实例接口返回。
    */
    @SerializedName("DealNames")
    @Expose
    private String [] DealNames;

    /**
     * 获取待查询的长订单号列表，创建实例、续费实例、扩容实例接口返回。
     * @return DealNames 待查询的长订单号列表，创建实例、续费实例、扩容实例接口返回。
     */
    public String [] getDealNames() {
        return this.DealNames;
    }

    /**
     * 设置待查询的长订单号列表，创建实例、续费实例、扩容实例接口返回。
     * @param DealNames 待查询的长订单号列表，创建实例、续费实例、扩容实例接口返回。
     */
    public void setDealNames(String [] DealNames) {
        this.DealNames = DealNames;
    }

    /**
     * 内部实现，用户禁止调用
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamArraySimple(map, prefix + "DealNames.", this.DealNames);

    }
}

==> tencentcloud-sdk-java-3.1.57-sources.jar: com/tencentcloudapi/mariadb/v20170312/models/DescribeOrdersRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.mariadb.v20170312.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DescribeOrdersRequest extends AbstractModel{

    /**
    * 待查询的长订单号列表，创建实例、续费实例、扩容实例接口返回。
    */
    @SerializedName("DealNames")
    @Expose
    private String [] DealNames;

    /**
     * Get 待查询的长订单号列表，创建实例、续费实例、扩容实例接口返回。 
     * @return DealNames 待查询的长订单号列表，创建实例、续费实例、扩容实例接口返回。
     */
    public String [] getDealNames() {
        return this.DealNames;
    }

    /**
     * Set 待查询的长订单号列表，创建实例、续费实例、扩容实例接口返回。
     * @param DealNames 待查询的长订单号列表，创建实例、续费实例、扩容实例接口返回。
     */
    public void setDealNames(String [] DealNames) {
        this.DealNames = DealNames;
    }

    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamArraySimple(map, prefix + "DealNames.", this.DealNames);

    }
}
